#!/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_6fo1nwbtjx/croot/gdal-split_1673969689280/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin/python
# EASY-INSTALL-SCRIPT: 'GDAL==3.0.2','gdal_edit.py'
__requires__ = 'GDAL==3.0.2'
__import__('pkg_resources').run_script('GDAL==3.0.2', 'gdal_edit.py')
